.. _statistics:

Autosubmit Statistics
=====================


When you click on the ``Statistics`` tab, you will see two input boxes: ``Section`` and ``Hours``, followed by the button ``Get Statistics``:

.. figure:: fig/fig_stat_1.jpg
   :name: experiment_stats
   :width: 100%
   :align: center
   :alt: Experiment Stat 1

   Experiment Statistics

There is also a brief explanation of the input fields and expected result. Basically, ``Section`` allows you to narrow your search to certain job types, and ``Hours`` allows you to set a time limit to look into the past in hours.

In this example we have queried 3 hours into the past:
 
.. figure:: fig/fig_stat_2.jpg
   :name: experiment_stats_open
   :width: 100%
   :align: center
   :alt: Experiment Stat 2

   Experiment Statistics (Last 3 hours)

Click on the button ``Clear Statistics`` to clear the results and submit another query.

.. important:: For more details about Autosubmit statistics, refer to: :ref:`autoStatistics`.